@@ -34,8 +34,8 @@ class Config(Dict):
             self._add_args(parser, key, value)
 
         options, params = parser.parse_known_args()
-        if params:
-            parsed_params = self._guess(params)
+        parsed_params = self._guess(params)
+        if parsed_params:
             options.__dict__.update(parsed_params)
             logging.getLogger().info(f'{params} is parsed as: {parsed_params}')
 
